@@ -1,13 +1,15 @@
 from PyQt6.QtCore import Qt, QObject, QEvent, QSize
 from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox, QTableWidget, QHeaderView, QApplication, QStyle, QStyledItemDelegate, QScrollArea
 from PyQt6.QtGui import QIcon, QTextDocument
+import os
+import sys
 import re
 import requests
-import importlib.resources
 
-main_directory = importlib.resources.files("gui_utilities")
-icons_directory = main_directory / "icons"
-tlds_path = main_directory / "tlds"
+def resource_path(relative_path):
+    if hasattr(sys, "_MEIPASS"): return os.path.join(sys._MEIPASS, relative_path)
+    base_path = os.path.dirname(__file__)
+    return os.path.join(base_path, relative_path)
 
 def _get_alignment_flag(aligment):
     if not isinstance(aligment, str): return aligment
@@ -410,10 +412,10 @@ def create_text_box(
     disabled_background_color = "#2d2d2d",
     disabled_border_width = 2,
     disabled_border_color = "#4a4a4a",
-    show_text_icon_url = str(icons_directory / "show_text_icon.png"),
-    hide_text_icon_url = str(icons_directory / "hide_text_icon.png"),
-    focused_show_text_icon_url = str(icons_directory / "focused_show_text_icon.png"),
-    focused_hide_text_icon_url = str(icons_directory / "focused_hide_text_icon.png"),
+    show_text_icon_url = resource_path("gui_utilities/icons/show_text_icon.png"),
+    hide_text_icon_url = resource_path("gui_utilities/icons/hide_text_icon.png"),
+    focused_show_text_icon_url = resource_path("gui_utilities/icons/focused_show_text_icon.png"),
+    focused_hide_text_icon_url = resource_path("gui_utilities/icons/focused_hide_text_icon.png"),
     hide_text = False,
     math_expression = False,
     parent = None
@@ -854,6 +856,7 @@ def create_information_message_box(
     message_box.setStyleSheet(style_sheet)
     main_layout = QVBoxLayout(message_box)
     message_box.setLayout(main_layout)
+    main_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
     main_layout.setContentsMargins(left_margin, top_margin, right_margin, bottom_margin)
     main_layout.setSpacing(spacing)
     text_label = create_label(
@@ -912,7 +915,7 @@ def create_confirmation_message_box(
     top_margin = 25,
     right_margin = 25,
     bottom_margin = 25,
-    main_spacing = 10,
+    spacing = 10,
     button_spacing = 10,
     background_color = "#1e1e1e",
     border_width = 2,
@@ -958,7 +961,7 @@ def create_confirmation_message_box(
     confirm_message_box = QDialog(parent)
     confirm_message_box.setObjectName("confirm_message_box")
     confirm_message_box.setWindowFlags(Qt.WindowType.FramelessWindowHint)
-    fixed_width = get_responsive_width(window, 3)
+    fixed_width = get_responsive_width(window, 4)
     if fixed_width is not None: confirm_message_box.setFixedWidth(fixed_width)
     style_sheet = f"""
         QDialog#confirm_message_box {{
@@ -970,8 +973,9 @@ def create_confirmation_message_box(
     confirm_message_box.setStyleSheet(style_sheet)
     main_layout = QVBoxLayout(confirm_message_box)
     confirm_message_box.setLayout(main_layout)
+    main_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
     main_layout.setContentsMargins(left_margin, top_margin, right_margin, bottom_margin)
-    main_layout.setSpacing(main_spacing)
+    main_layout.setSpacing(spacing)
     text_label = create_label(
         text = text,
         font_family = label_font_family,
@@ -1322,7 +1326,7 @@ def validate_cellphone_number(cellphone_number):
     if len(clean_number) == 10: return None
     return "No ha ingresado un número telefónico válido."
 
-tlds_list_path = main_directory / tlds_path / "tlds_list.txt"
+tlds_list_path = resource_path("gui_utilities/tlds/tlds_list.txt")
 
 def export_tlds(tlds_list):
     try:
@@ -1347,8 +1351,8 @@ def get_tlds():
 def build_email_pattern(tlds_list):
     if not tlds_list:
         return re.compile(
-            r"^(?P<local>[a-zA-Z0-9!#$%&'*+/=?^_`{|}~-]+" 
-            r"(?:\[a-zA-Z0-9!#$%&'*+/=?^_`{|}~-]+)*)@" 
+            r"^(?P<local>[a-zA-Z0-9!#$%&'*+/=?^_`{|}~-]+"
+            r"(?:\[a-zA-Z0-9!#$%&'*+/=?^_`{|}~-]+)*)@"
             r"(?P<dominio>(?:[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?\.)+"
             r"[a-zA-Z]{2,63})$",
             re.IGNORECASE
@@ -1391,12 +1395,11 @@ def format_date(date):
 
 def format_html(expression):
     html_expression = expression
-    html_expression = re.sub(r"\\frac\{(.*?)\}\{(.*?)\}", r"<span style='font-size:90%;'>\1⁄\2</span>", html_expression)
+    html_expression = re.sub(r"\\frac\{(.*?)\}\{(.*?)\}", r"""<span style = "white-space: normal;">\1⁄\2</span>""", html_expression)
     html_expression = re.sub(r"_\{([^}]+)\}", r"<sub>\1</sub>", html_expression)
     html_expression = re.sub(r"\^\{([^}]+)\}", r"<sup>\1</sup>", html_expression)
     html_expression = re.sub(r"_([a-zA-Z0-9]+)", r"<sub>\1</sub>", html_expression)
     html_expression = re.sub(r"\^([a-zA-Z0-9]+)", r"<sup>\1</sup>", html_expression)
-    html_expression = html_expression.replace(" ", "&nbsp;")
     return html_expression
 
 def convert_to_float(number): return float(number.replace(".", "").replace(",", "."))
